@@ -16,12 +16,12 @@ from __future__ import annotations
 
 import importlib
 import inspect
-from pprint import pprint
+import typing
 from typing import List, Type
 
 import firefly.domain as ffd
+import firefly_di as di
 import inflection
-import typing
 
 
 class LoadApplicationLayer(ffd.ApplicationService):
@@ -33,10 +33,15 @@ class LoadApplicationLayer(ffd.ApplicationService):
     _message_factory: ffd.MessageFactory = None
     _rest_router: ffd.RestRouter = None
     _system_bus: ffd.SystemBus = None
+    _deferred: List[tuple] = []
 
     def __call__(self, **kwargs):
+        self._deferred = []
         for context in self._context_map.contexts:
             for cls in self._load_module(context):
+                if cls.has_annotations():
+                    for annotation in cls.get_annotations():
+                        annotation.configure(cls, context.container)
                 if issubclass(cls, ffd.ApplicationService):
                     self._register_service(cls, context)
                     self._add_endpoints(cls, context)
@@ -46,6 +51,14 @@ class LoadApplicationLayer(ffd.ApplicationService):
                 if issubclass(entity, ffd.AggregateRoot):
                     self._add_endpoints(entity, context)
 
+        for deferred in self._deferred:
+            if deferred[0] == 'event':
+                self._system_bus.add_event_listener(deferred[1], **deferred[2])
+            elif deferred[0] == 'command':
+                self._system_bus.add_command_handler(deferred[1], **deferred[2])
+            elif deferred[0] == 'query':
+                self._system_bus.add_query_handler(deferred[1], **deferred[2])
+
         self.dispatch(ffd.ApplicationLayerLoaded())
 
     def _add_middleware(self, cls: Type[ffd.Middleware], context: ffd.Context):
@@ -57,14 +70,19 @@ class LoadApplicationLayer(ffd.ApplicationService):
             params['index'] = config['index']
         elif config['cb'] is not None:
             params['cb'] = config['cb']
+        if config['replace'] is not None:
+            params['replace'] = config['replace']
 
         built = context.container.build(cls)
         if config['buses'] is None or 'event' in config['buses']:
-            self._system_bus.add_event_listener(built, **params)
+            if self._system_bus.add_event_listener(built, **params) is False:
+                self._deferred.append(('event', built, params))
         if config['buses'] is None or 'command' in config['buses']:
-            self._system_bus.add_command_handler(built, **params)
+            if self._system_bus.add_command_handler(built, **params) is False:
+                self._deferred.append(('command', built, params))
         if config['buses'] is None or 'query' in config['buses']:
-            self._system_bus.add_query_handler(built, **params)
+            if self._system_bus.add_query_handler(built, **params) is False:
+                self._deferred.append(('query', built, params))
 
     def _register_service(self, cls: Type[ffd.ApplicationService], context: ffd.Context):
         if cls.is_agent():
@@ -143,7 +161,7 @@ class LoadApplicationLayer(ffd.ApplicationService):
         for k, v in module.__dict__.items():
             if not inspect.isclass(v):
                 continue
-            if issubclass(v, (ffd.ApplicationService, ffd.Middleware)):
+            if issubclass(v, (ffd.ApplicationService, ffd.Middleware, ffd.MetaAware)):
                 ret.append(v)
 
         return ret
